@@ -22,6 +22,24 @@ class TString :
     def ConvertCTypeStringToUnicode(x) :
         return x.decode('utf-8')
 
+    def CStrToPyStr(byteData) :
+
+        strLen = 0
+        for idx, value in enumerate(byteData) :
+            if value == 0 :
+                strLen = idx
+                break
+
+        newByteData = bytearray(strLen) 
+        for idx, value in enumerate(byteData) :
+            if value != 0 :
+                newByteData[idx] = value
+            else :
+                break;
+
+        return newByteData.decode('utf-8')
+
+
 class TPower :
 
     class Type(enum.IntEnum) :
@@ -523,6 +541,95 @@ class TDeviceBase(metaclass=ABCMeta) :
     @abstractmethod
     def AgingMeasureADCResultStructureByteSize(this) : pass
 
+    #COMM_API int TedAdcGetInvalidValue();
+    @abstractmethod
+    def AdcGetInvalidValue(this) : pass
+
+    #COMM_API int TedAdcGetGroupCount(int dutIdx);
+    @abstractmethod
+    def AdcGetGroupCount(this, dutIdx) : pass
+
+    #COMM_API Bool TedAdcGetGroupName(int dutIdx, int groupIdx, char* szGroupName);
+    @abstractmethod
+    def AdcGetGroupName(this, dutIdx, grpIdx) : pass
+
+    #COMM_API int TedAdcGetGroupIndexByName(int dutIdx, const char* groupName);
+    @abstractmethod
+    def AdcGetGroupIndexByName(this, dutIdx, grpName) : pass
+
+    #COMM_API int TedAdcGetChannelCount(int dutIdx, int groupIdx);
+    @abstractmethod
+    def AdcGetChannelCount(this, dutIdx, grpIdx) : pass
+
+    #COMM_API Bool TedAdcGetChannelName(int dutIdx, int groupIdx, int chIdx, /*OUT*/ char* szChName);
+    @abstractmethod
+    def AdcGetChannelName(this, dutIdx, grpIdx, chIdx) : pass
+
+    #COMM_API int TedAdcGetGroupIndexByPsID(int dutIdx, int psID);
+    @abstractmethod
+    def AdcGetGroupIndexByPsID(this, dutIdx, psID) : pass
+
+    #COMM_API int TedAdcGetChannelIndexByPsID(int dutIdx, int psID);
+    @abstractmethod
+    def AdcGetChannelIndexByPsID(this, dutIdx, psID) : pass
+
+    #COMM_API Bool TedAdcSetDevConfig(int dutIdx, int groupIdx, int value);
+    @abstractmethod
+    def AdcSetDevConfig(this, dutIdx, grpIdx, value) : pass
+
+    #COMM_API int TedAdcGetDevConfig(int dutIdx, int groupIdx);
+    @abstractmethod
+    def AdcGetDevConfig(this, dutIdx, grpIdx) : pass
+
+    #COMM_API Bool TedAdcSetInConfig(int dutIdx, int groupIdx, int chIdx, int value);
+    @abstractmethod
+    def AdcSetInConfig(this, dutIdx, grpIdx, value) : pass
+
+    #COMM_API int TedAdcGetInConfig(int dutIdx, int groupIdx, int chIdx);
+    @abstractmethod
+    def AdcGetInConfig(this, dutIdx, grpIdx, chIdx) : pass
+
+    #COMM_API int TedAdcGetVoltage(int dutIdx, int groupIdx, int chIdx);
+    @abstractmethod
+    def AdcGetVoltage(this, dutIdx, grpIdx, chIdx) : pass
+
+    #COMM_API int TedAdcGetVoltageByPsID(int dutIdx, int psID);
+    @abstractmethod
+    def AdcGetVoltageByPsID(this, dutIdx, psID) : pass
+
+    #COMM_API float TedAdcGetVoltFloatByPsID(int dutIdx, int psID);
+    @abstractmethod
+    def AdcGetVoltFloatByPsID(this, dutIdx, psID) : pass
+
+    #COMM_API Bool TedAdcGetAllVoltage(int dutIdx, int groupIdx, int* valueArray);
+    @abstractmethod
+    def AdcGetAllVoltage(this, dutIdx, grpIdx) : pass
+
+    #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
+    @abstractmethod
+    def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) : pass
+
+    #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
+    @abstractmethod
+    def AdcGetCurrentByPsID(this, dutIdx, psID) : pass
+
+    #COMM_API float TedAdcGetCurrFloatByPsID(int dutIdx, int psID);
+    @abstractmethod
+    def AdcGetCurrFloatByPsID(this, dutIdx, psID) : pass
+
+    #COMM_API Bool TedAdcGetAllCurrent(int dutIdx, int groupIdx, int* valueArray);
+    @abstractmethod
+    def AdcGetAllCurrent(this, dutIdx, grpIdx) : pass
+
+    #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
+    @abstractmethod
+    def AdcSoutSetRBSel(this, dutIdx, value) : pass
+
+    #COMM_API int TedAdcSoutGetRBSel(int dutIdx);
+    @abstractmethod
+    def AdcSoutGetRBSel(this, dutIdx) : pass
+
+
 #
 # class TFileTransfer
 #
