@@ -980,15 +980,15 @@ class TDeviceWin(TDeviceBase) :
 
     #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
     def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) :
-        return this.__Api.TDeviceAdcGetCurrent(dutIdx, grpIdx, chIdx)
+        return this.__Api.TDeviceAdcGetCurrent(this.__DeviceHandle, dutIdx, grpIdx, chIdx)
 
     #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
     def AdcGetCurrentByPsID(this, dutIdx, psID) :
-        return this.__Api.TDeviceAdcGetCurrentByPsID(dutIdx, psID)
+        return this.__Api.TDeviceAdcGetCurrentByPsID(this.__DeviceHandle, dutIdx, psID)
 
     #COMM_API float TedAdcGetCurrFloatByPsID(int dutIdx, int psID);
     def AdcGetCurrFloatByPsID(this, dutIdx, psID) :
-        return this.__Api.TDeviceAdcGetCurrFloatByPsID(dutIdx, psID)
+        return this.__Api.TDeviceAdcGetCurrFloatByPsID(this.__DeviceHandle, dutIdx, psID)
 
     #COMM_API Bool TedAdcGetAllCurrent(int dutIdx, int groupIdx, int* valueArray);
     def AdcGetAllCurrent(this, dutIdx, grpIdx) :
@@ -1006,11 +1006,11 @@ class TDeviceWin(TDeviceBase) :
 
     #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
     def AdcSoutSetRBSel(this, dutIdx, value) :
-        return this.__Api.TDeviceAdcSoutSetRBSel(dutIdx, value)
+        return this.__Api.TDeviceAdcSoutSetRBSel(this.__DeviceHandle, dutIdx, value)
 
     #COMM_API int TedAdcSoutGetRBSel(int dutIdx);
     def AdcSoutGetRBSel(this, dutIdx) :
-        return this.__Api.TDeviceAdcSoutGetRBSel(dutIdx)
+        return this.__Api.TDeviceAdcSoutGetRBSel(this.__DeviceHandle, dutIdx)
 
 
 #
